# test_run.py
# See LICENSE file for full license details.
# Copyright (c) 2024, National Institute of Advanced Industrial Science and Technology (AIST). All rights reserved.


from pathlib import Path

def test_run():
    import numpy as np
    import pandas as pd
    from fnvc import FaultHDBSCAN

    # Sample dataset (random values)
    df_input = pd.read_csv(
        Path(__file__).parent.parent/'examples'/'sample1'/'points.txt', 
        sep=r'\s+', header=None, 
        names=('E','N','D'),
    )

    # Parameters for computing point-cloud normal vectors
    max_neighbors_normal_vector = 150 
    min_neighbors_normal_vector = 20
    max_dist_neighbors = 2.0
    min_planarity = 1.25 

    # Initialize FaultHDBSCAN
    clusterer = FaultHDBSCAN(
        max_neighbors_normal_vector=max_neighbors_normal_vector,
        min_neighbors_normal_vector=min_neighbors_normal_vector,
        max_dist_neighbors=max_dist_neighbors,
        min_planarity=min_planarity,
    )

    # Load point-cloud data and compute point-cloud normal vectors
    clusterer.calc_normal_vector(
        df_input,
        id_points=df_input.index.values,
        standardize=True, # standardize positions
        max_workers=2, # parallel computing
    )

    # Execute HDBSCAN 
    clusterer.fit_predict(
        min_cluster_size=5,
        min_samples=5,
        cluster_selection_epsilon=0.000,
    )

    # Return the result as dataframes:
    # results_clustering: dataframe for extracted fault parameters
    # output_events: dataframe for hypocenter cluster numbers 
    results_clustering, output_events = clusterer.output_planes(key=0)

    